# @(#)19  1.6 src/cmdline/staging/scripts/delete_partners.py, amws.cmdline, fim611, 060921a 9/18/06 16:18:34
# (C) Copyright International Business Machines Corporation 2005. All rights
# reserved.  U.S. Government Users Restricted Rights -- Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 
import sys, fim_base
from fed_utils import get_partner, get_partners
from domain_utils import is_domain_present
from com.tivoli.am.fim.logging import FIMLoggerFactory
from com.tivoli.am.fim.logging import FIMLogger
from com.tivoli.am.fim.logging import FIMLevel
from com.tivoli.am.fim.i18n.msgs import CmdLineMessages
from jarray import array
from java.lang import Object
from com.tivoli.am.fim.logging import FIMLoggerConstants

# Set up FIMLogger
component_name = "StagingTools"
script_name = "delete_partners.py"
method_name = script_name
class_name = "com.tivoli.am.fim.cmdline." + script_name[0:-3]
FIMLoggerFactory.enableStdout(FIMLevel.ALL)
FIMLoggerFactory.setPreferredFIMLoggerImpl(FIMLoggerConstants.FIMLOGGER_BASE_IMPL)
log = FIMLoggerFactory.getFIMLogger(component_name, class_name, CmdLineMessages.CLASS_NAME)

def usage():
    inserts = array([script_name],Object)
    log.logMessage(FIMLevel.INFO, method_name, CmdLineMessages.usage_delete_partners, \
        inserts)
    raise SystemExit

if __name__ == 'main':

    if len(sys.argv) < 3:
        usage()
        
    props_file = sys.argv[0]
    fed_name = sys.argv[1]
    domain_props = fim_base.read_properties_file(props_file)
    if not is_domain_present(domain_props):
        raise SystemExit    
    
    if (sys.argv[2] == "-all"):
        (fed_mgr, sec_tok_mgr) = fim_base.prepare_mgr_objs(domain_props, "delete_partners")
        fed = fed_mgr.getFederationByDisplayName(fed_name, sec_tok_mgr)
        
        # Loop through all partners and remove each one
        partner_dict = get_partners(fed)
        for partner_name in partner_dict.values():
            fed.removePartner(get_partner(fed, partner_name))
        
        # Check to see if any partners still exist and print results
        partner_dict = get_partners(fed)
        if not partner_dict.keys():            
            inserts = array([fed_name], Object)
            log.logMessage(FIMLevel.INFO, method_name, \
                CmdLineMessages.deleted_all_partners_in_federation, inserts) 
            # Commit the changes           
            fim_base.commit_session(fed_mgr)        
        else:
            inserts = array([fed_name], Object)
            log.logMessage(FIMLevel.WARNING, method_name, \
                CmdLineMessages.unable_to_delete_all_partners_in_federation, inserts)        
    else:
        partner_name = sys.argv[2]
        (fed_mgr, sec_tok_mgr) = fim_base.prepare_mgr_objs(domain_props, "delete_partners")
        fed = fed_mgr.getFederationByDisplayName(fed_name, sec_tok_mgr)
 
        partner = get_partner(fed, partner_name)
        if partner:
            fed.removePartner(partner) # remove specified partner
        else:
            # Given partner does not exist in the specified federation
            inserts = array([partner_name, fed_name], Object)
            log.logMessage(FIMLevel.INFO, method_name, \
                CmdLineMessages.partner_does_not_exist, inserts)
            raise SystemExit
        
        # Check to see if partner still exists and print results
        if not get_partner(fed, partner_name):
            inserts = array([partner_name, fed_name], Object)
            log.logMessage(FIMLevel.INFO, method_name, \
                CmdLineMessages.deleted_partner_in_federation, inserts)
            fim_base.commit_session(fed_mgr)
        else:
            inserts = array([partner_name, fed_name], Object)
            log.logMessage(FIMLevel.WARNING, method_name, \
                CmdLineMessages.unable_to_delete_partner_in_federation, inserts)
    raise SystemExit
